Class: Google::Cloud::Monitoring::V3::UpdateGroupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/monitoring/v3/group_service.rb

Overview

The UpdateGroup request.

Instance Attribute Summary collapse

Instance Attribute Details

#group ⇒ ::Google::Cloud::Monitoring::V3::Group

Returns Required. The new definition of the group. All fields of the existing group, excepting name, are replaced with the corresponding fields of this group.

Returns:

  • (::Google::Cloud::Monitoring::V3::Group) —

    Required. The new definition of the group. All fields of the existing group, excepting name, are replaced with the corresponding fields of this group.



132
133
134
135
# File 'proto_docs/google/monitoring/v3/group_service.rb', line 132

class UpdateGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only ⇒ ::Boolean

Returns If true, validate this request but do not update the existing group.

Returns:

  • (::Boolean) —

    If true, validate this request but do not update the existing group.



132
133
134
135
# File 'proto_docs/google/monitoring/v3/group_service.rb', line 132

class UpdateGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end