Module: Google::Cloud::Monitoring::V3::UptimeCheckService
- Defined in:
- lib/google/cloud/monitoring/v3/uptime_check_service.rb,
lib/google/cloud/monitoring/v3/uptime_check_service/paths.rb,
lib/google/cloud/monitoring/v3/uptime_check_service/client.rb,
lib/google/cloud/monitoring/v3/uptime_check_service/credentials.rb
Overview
The UptimeCheckService API is used to manage (list, create, delete, edit) Uptime check configurations in the Cloud Monitoring product. An Uptime check is a piece of configuration that determines which resources and services to monitor for availability. These configurations can also be configured interactively by navigating to the [Cloud console] (https://console.cloud.google.com), selecting the appropriate project, clicking on "Monitoring" on the left-hand side to navigate to Cloud Monitoring, and then clicking on "Uptime".
Defined Under Namespace
Modules: Paths Classes: Client, Credentials